==> AgeOn1.8.2_source.zip: AgeOn1.8.2_source/nispi/Controls/Menu/ContextMenu/ThreadList/BrowserTextMenu.cs <==
﻿//ライセンス情報はAgeOnフォルダのLISENCEフォルダを参照してください
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Diagnostics;
using System.Drawing;

using nispi;

using nispi.controlclass;

namespace nispi.Menu
{
    class BrowserTextMenu
    {
        public ContextMenuStripParts contextMenuStripParts;

        /*選択されたテキストがある場合*/
        public ToolStripMenuItemParts menuItemOpenGoogleParts;
        public ToolStripMenuItemParts menuItemOpenWikiParts;
        public ToolStripMenuItemParts menuItemCopyParts;
        public ToolStripMenuItemParts menuItemSamplingParts;

        public TextMenuEvent textMenuEvent;
        //使いたくない場合のスイッチ
        public bool on = true;

        public BrowserTextMenu()
        {
            contextMenuStripParts = ContextMenuStripPartsManager.Pop();

            /*選択されたテキストがある場合*/
            menuItemOpenGoogleParts = ToolStripMenuItemPartsManager.Pop();
            menuItemOpenWikiParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyParts = ToolStripMenuItemPartsManager.Pop();
            menuItemSamplingParts = ToolStripMenuItemPartsManager.Pop();

            //選択されたテキストがある場合
            menuItemOpenGoogleParts.Text = '\"' + "" + '\"' + "をGoogleで検索(&G)";
            menuItemOpenWikiParts.Text = '\"' + "" + '\"' + "をWikiで開く(&W)";
            menuItemCopyParts.Text = "コピー";
            menuItemSamplingParts.Text = '\"' + "" + '\"' + "を抽出表示(&Z)";

            contextMenuStripParts.ItemsAdd(menuItemOpenGoogleParts);
            contextMenuStripParts.ItemsAdd(menuItemOpenWikiParts);
            contextMenuStripParts.ItemsAdd("-");
            contextMenuStripParts.ItemsAdd(menuItemCopyParts);
            contextMenuStripParts.ItemsAdd("-");
            contextMenuStripParts.ItemsAdd(menuItemSamplingParts);

            textMenuEvent = new TextMenuEvent(this);
        }
    }
}

==> AgeOn2.5_source.zip: AgeOn2.5_source/nispi/Controls/Menu/ContextMenu/ThreadList/BrowserTextMenu.cs <==
﻿//ライセンス情報はAgeOnフォルダのLISENCEフォルダを参照してください
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Diagnostics;
using System.Drawing;

using nispi;

using nispi.controlclass;

namespace nispi.Menu
{
    class BrowserTextMenu
    {
        public ContextMenuStripParts contextMenuStripParts;

        /*選択されたテキストがある場合*/
        public ToolStripMenuItemParts menuItemOpenGoogleParts;
        public ToolStripMenuItemParts menuItemOpenWikiParts;
        public ToolStripMenuItemParts menuItemCopyParts;
        public ToolStripMenuItemParts menuItemSamplingParts;

        public TextMenuEvent textMenuEvent;
        //使いたくない場合のスイッチ
        public bool on = true;

        public BrowserTextMenu()
        {
            contextMenuStripParts = ContextMenuStripPartsManager.Pop();

            /*選択されたテキストがある場合*/
            menuItemOpenGoogleParts = ToolStripMenuItemPartsManager.Pop();
            menuItemOpenWikiParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyParts = ToolStripMenuItemPartsManager.Pop();
            menuItemSamplingParts = ToolStripMenuItemPartsManager.Pop();

            //選択されたテキストがある場合
            menuItemOpenGoogleParts.Text = '\"' + "" + '\"' + "をGoogleで検索(&G)";
            menuItemOpenWikiParts.Text = '\"' + "" + '\"' + "をWikiで開く(&A)";
            menuItemCopyParts.Text = "コピー";
            menuItemSamplingParts.Text = '\"' + "" + '\"' + "を抽出表示(&Z)";

            contextMenuStripParts.ItemsAdd(menuItemOpenGoogleParts);
            contextMenuStripParts.ItemsAdd(menuItemOpenWikiParts);
            contextMenuStripParts.ItemsAdd("-");
            contextMenuStripParts.ItemsAdd(menuItemCopyParts);
            contextMenuStripParts.ItemsAdd("-");
            contextMenuStripParts.ItemsAdd(menuItemSamplingParts);

            textMenuEvent = new TextMenuEvent(this);
        }
    }
}
